==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/Chmod.java <==
/*
 * Copyright (c) 2011 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on 27-07-2011
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */
package de.fzj.unicore.ucc.actions;

import java.util.regex.Pattern;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.OptionBuilder;
import org.unigrids.x2006.x04.services.sms.PermissionsChangeModeType;
import org.unigrids.x2006.x04.services.sms.PermissionsClassType;

import de.fzj.unicore.uas.client.StorageClient;

/**
 * Changes basic access permissions of a given path.
 * 
 * @author K. Benedyczak
 */
public class Chmod extends SMSOperation {
	public static final Pattern pattern = Pattern.compile("[r-][w-][x-]");		

	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_RECURSIVE_LONG)
				.withDescription("Recursively applies the operation to the whole contents of the direcotry specified as an argument.")
				.isRequired(false)
				.create(OPT_RECURSIVE)
				);
	}

	@Override
	public String getName() {
		return "chmod";
	}

	@Override
	public String getSynopsis() {
		return "Changes access permissions of a file on a remote storage.";
	}
	
	@Override
	public String getDescription(){
		return "change file's access permissions";
	}
	
	@Override
	public String getArgumentList(){
		return "<u|g|o><-|+|=><r|-><w|-><x|-> <[Storage-URL#]/path or [u6://SITENAME/[JobId|StorageName]]/path>";
	}
	
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
	
	
	@Override
	public void process() {
		super.process();
		boolean recursive = getBooleanOption(OPT_RECURSIVE_LONG, OPT_RECURSIVE);
		verbose("Recursive invocation = " + recursive);
		CommandLine cmdLine = getCommandLine(); 
		if (cmdLine.getArgs().length != 3) {
			error("Wrong number of arguments", null);
			printUsage();
			endProcessing(ERROR_CLIENT);
		}
		String spec = cmdLine.getArgs()[1];
		String target = cmdLine.getArgs()[2];
		
		verbose("Setting access on " + target);
		
		if (spec.length() != 5)
			errorPerm(spec);
		char[] specC = spec.toCharArray();
		
		PermissionsChangeModeType.Enum mode = null;
		PermissionsClassType.Enum permClass = null;
		
		switch (specC[0])
		{
		case 'u':
			permClass = PermissionsClassType.USER;
			break;
		case 'g':
			permClass = PermissionsClassType.GROUP;
			break;
		case 'o':
			permClass = PermissionsClassType.OTHER;
			break;
		default:
			errorPerm(spec);
		}
		
		switch (specC[1])
		{
		case '-':
			mode = PermissionsChangeModeType.SUBTRACT;
			break;
		case '+':
			mode = PermissionsChangeModeType.ADD;			
			break;
		case '=':
			mode = PermissionsChangeModeType.SET;
			break;
		default:
			errorPerm(spec);
		}
		
		String perms = spec.substring(2);
		if (!pattern.matcher(perms).matches())
			errorPerm(spec);
			
		StorageClient sms = getStorageClient(target);
		try{
			String path = getPathAtStorage(target);
			
			sms.changePermissions2(path, mode, permClass, perms, recursive);
		}catch(Exception ex){
			error("Can't change permissions.",ex);
			endProcessing(ERROR);
		}
	}
	
	private void errorPerm(String perm) {
		error("Invalid format of permission specification: " + perm, null);
		printUsage();
		endProcessing(ERROR_CLIENT);		
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/main/java/de/fzj/unicore/ucc/actions/Chmod.java <==
/*
 * Copyright (c) 2011 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on 27-07-2011
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */
package de.fzj.unicore.ucc.actions;

import java.util.regex.Pattern;

import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.OptionBuilder;
import org.unigrids.x2006.x04.services.sms.PermissionsChangeModeType;
import org.unigrids.x2006.x04.services.sms.PermissionsClassType;

import de.fzj.unicore.uas.client.StorageClient;

/**
 * Changes basic access permissions of a given path.
 * 
 * @author K. Benedyczak
 */
public class Chmod extends SMSOperation {
	public static final Pattern pattern = Pattern.compile("[r-][w-][Xx-]");		

	
	@Override
	@SuppressWarnings("all")
	protected void createOptions() {
		super.createOptions();
		getOptions().addOption(OptionBuilder.withLongOpt(OPT_RECURSIVE_LONG)
				.withDescription("Recursively applies the operation to the whole contents of the direcotry specified as an argument.")
				.isRequired(false)
				.create(OPT_RECURSIVE)
				);
	}

	@Override
	public String getName() {
		return "chmod";
	}

	@Override
	public String getSynopsis() {
		return "Changes access permissions of a file on a remote storage.";
	}
	
	@Override
	public String getDescription(){
		return "change file's access permissions";
	}
	
	@Override
	public String getArgumentList(){
		return "<u|g|o><-|+|=><r|-><w|-><x|X|-> <[Storage-URL#]/path or [u6://SITENAME/[JobId|StorageName]]/path>";
	}
	
	@Override
	public String getCommandGroup(){
		return "Data management";
	}
	
	
	@Override
	public void process() {
		super.process();
		boolean recursive = getBooleanOption(OPT_RECURSIVE_LONG, OPT_RECURSIVE);
		verbose("Recursive invocation = " + recursive);
		CommandLine cmdLine = getCommandLine(); 
		if (cmdLine.getArgs().length != 3) {
			error("Wrong number of arguments", null);
			printUsage();
			endProcessing(ERROR_CLIENT);
		}
		String spec = cmdLine.getArgs()[1];
		String target = cmdLine.getArgs()[2];
		
		verbose("Setting access on " + target);
		
		if (spec.length() != 5)
			errorPerm(spec);
		char[] specC = spec.toCharArray();
		
		PermissionsChangeModeType.Enum mode = null;
		PermissionsClassType.Enum permClass = null;
		
		switch (specC[0])
		{
		case 'u':
			permClass = PermissionsClassType.USER;
			break;
		case 'g':
			permClass = PermissionsClassType.GROUP;
			break;
		case 'o':
			permClass = PermissionsClassType.OTHER;
			break;
		default:
			errorPerm(spec);
		}
		
		switch (specC[1])
		{
		case '-':
			mode = PermissionsChangeModeType.SUBTRACT;
			break;
		case '+':
			mode = PermissionsChangeModeType.ADD;			
			break;
		case '=':
			mode = PermissionsChangeModeType.SET;
			break;
		default:
			errorPerm(spec);
		}
		
		String perms = spec.substring(2);
		if (!pattern.matcher(perms).matches())
			errorPerm(spec);
			
		StorageClient sms = getStorageClient(target);
		try{
			String path = getPathAtStorage(target);
			
			sms.changePermissions2(path, mode, permClass, perms, recursive);
		}catch(Exception ex){
			error("Can't change permissions.",ex);
			endProcessing(ERROR);
		}
	}
	
	private void errorPerm(String perm) {
		error("Invalid format of permission specification: " + perm, null);
		printUsage();
		endProcessing(ERROR_CLIENT);		
	}
}
